@@ -33,7 +33,9 @@
  * Contributor(s):   Andrzej Porebski (bug fix);
  *                   Jonathan Nash (bug fix);
  *                   Richard Atkinson;
- *                   Andreas Schroeder;
+ *                   Andreas Schroeder (beatification)
+ *
+ * $Id: DatasetUtilities.java,v 1.18.2.5 2007/03/15 17:04:35 mungady Exp $
  *
  * Changes (from 18-Sep-2001)
  * --------------------------
@@ -118,8 +120,8 @@ import org.jfree.data.category.CategoryDataset;
 import org.jfree.data.category.DefaultCategoryDataset;
 import org.jfree.data.category.IntervalCategoryDataset;
 import org.jfree.data.function.Function2D;
-import org.jfree.data.xy.IntervalXYDataset;
 import org.jfree.data.xy.OHLCDataset;
+import org.jfree.data.xy.IntervalXYDataset;
 import org.jfree.data.xy.TableXYDataset;
 import org.jfree.data.xy.XYDataset;
 import org.jfree.data.xy.XYSeries;
@@ -590,14 +592,20 @@ public final class DatasetUtilities {
      * @return A boolean.
      */
     public static boolean isEmptyOrNull(XYDataset dataset) {
+
+        boolean result = true;
+
         if (dataset != null) {
             for (int s = 0; s < dataset.getSeriesCount(); s++) {
                 if (dataset.getItemCount(s) > 0) {
-                    return false;
+                    result = false;
+                    continue;
                 }
             }
         }
-        return true;
+
+        return result;
+
     }
 
     /**
@@ -706,7 +714,8 @@ public final class DatasetUtilities {
     }
     
     /**
-     * Returns the range of values in the range for the dataset.
+     * Returns the range of values in the range for the dataset.  This method
+     * is the partner for the getDomainExtent method.
      *
      * @param dataset  the dataset (<code>null</code> not permitted).
      *
@@ -717,7 +726,8 @@ public final class DatasetUtilities {
     }
     
     /**
-     * Returns the range of values in the range for the dataset.
+     * Returns the range of values in the range for the dataset.  This method
+     * is the partner for the getDomainExtent method.
      *
      * @param dataset  the dataset (<code>null</code> not permitted).
      * @param includeInterval  a flag that determines whether or not the
@@ -1506,8 +1516,6 @@ public final class DatasetUtilities {
      * @param dataset  the dataset (<code>null</code> not permitted).
      * 
      * @return The range.
-     * 
-     * @see #findRangeBounds(CategoryDataset)
      */
     public static Range findCumulativeRangeBounds(CategoryDataset dataset) {
         
